@@ -9,12 +9,6 @@ from pybuilder.core import depends
 
 from anybadge import Badge
 
-URL = {
-    'complexity': 'https://radon.readthedocs.io/en/latest/api.html#module-radon.complexity',
-    'severity': 'https://pypi.org/project/bandit/',
-    'python': 'https://www.python.org/downloads/'
-}
-
 
 @init
 def init_anybadge(project):
@@ -28,7 +22,7 @@ def init_anybadge(project):
 
 @task('anybadge', description='generate badges from reports using anybadge')
 @depends('prepare')
-def anybadge(project, logger):
+def anybadge(project, logger, reactor):
     """ generate badges from reports using anybadge
     """
     reports_directory = project.expand_path('$dir_reports')
@@ -37,27 +31,28 @@ def anybadge(project, logger):
     exclude = get_badge_exclude(project)
     logger.debug(f'task instructed to exclude {exclude}')
     if 'complexity' not in exclude:
-        report_path = os.path.join(reports_directory, 'radon')
-        badge_path = os.path.join(images_directory, 'complexity.svg')
+        report_path = f'{reports_directory}/radon'
+        badge_path = f'{images_directory}/complexity.svg'
         use_average = project.get_property('anybadge_complexity_use_average')
         create_complexity_badge(report_path, badge_path, logger, add_to_readme, use_average)
     if 'severity' not in exclude:
-        report_path = os.path.join(reports_directory, 'bandit.json')
-        badge_path = os.path.join(images_directory, 'severity.svg')
+        report_path = f'{reports_directory}/bandit.json'
+        badge_path = f'{images_directory}/severity.svg'
         create_severity_badge(report_path, badge_path, logger, add_to_readme)
     if 'coverage' not in exclude:
-        report_path = os.path.join(reports_directory, 'coverage.json')
-        badge_path = os.path.join(images_directory, 'coverage.svg')
+        report_path = f'{reports_directory}/{project.name}_coverage.json'
+        badge_path = f'{images_directory}/coverage.svg'
         create_coverage_badge(report_path, badge_path, logger, add_to_readme)
     if 'python' not in exclude:
-        badge_path = os.path.join(images_directory, 'python.svg')
+        badge_path = f'{images_directory}/python.svg'
         create_python_badge(badge_path, logger, add_to_readme)
 
 
 def get_images_directory(project):
     """ return images directory and create directory if does not already exist
     """
-    images_directory = os.path.join(project.basedir, 'docs', 'images')
+    target_directory = project.expand_path('$dir_target')
+    images_directory = target_directory.replace('/target', '/docs/images')
     if not os.path.exists(images_directory):
         os.makedirs(images_directory)
     return images_directory
@@ -66,12 +61,10 @@ def get_images_directory(project):
 def get_badge_exclude(project):
     """ return list of badges to exclude
     """
-    exclusions = []
     exclude = project.get_property('anybadge_exclude')
     if exclude:
-        items = exclude.split(',')
-        exclusions = [item.strip() for item in items]
-    return exclusions
+        return exclude.split(',')
+    return []
 
 
 def accessible(filename):
@@ -109,17 +102,16 @@ def get_complexity_report(lines):
         line = line.strip()
         match = re.match(regex_score, line)
         if match:
-            score = round(float(match.group('score')))
+            score = float(match.group('score'))
             if score > report['highest']['score']:
                 report['highest']['score'] = score
                 report['highest']['name'] = match.group('name')
 
     last_line = lines[-1].strip()
     regex_average = r'Average complexity: [A-Z] \((?P<average>.*)\)'
-    match_average = re.match(regex_average, last_line)
-    if match_average:
-        average = match_average.group('average')
-        report['average'] = round(float(average), 2)
+    match = re.match(regex_average, last_line)
+    if match:
+        report['average'] = float(match.group('average'))
 
     return report
 
@@ -143,7 +135,7 @@ def get_complexity_badge(complexity_report, use_average=False):
         color = 'green'
     elif score <= 10:
         value = 'Stable'
-        color = 'olive'
+        color = 'green'
     elif score <= 20:
         value = 'Slight'
         color = 'yellow'
@@ -157,7 +149,7 @@ def get_complexity_badge(complexity_report, use_average=False):
         value = 'Unstable'
         color = 'brightred'
 
-    return Badge('complexity', value=f'{value}: {score}', default_color=color, num_padding_chars=1)
+    return Badge('complexity', value=value, default_color=color, num_padding_chars=1)
 
 
 def get_severity_badge(severity_report):
@@ -206,7 +198,7 @@ def get_coverage_badge(coverage):
         color = 'orange'
     if coverage < 55:
         color = 'red'
-    value = f'{round(coverage, 2)}%'
+    value = f'{coverage}%'
     return Badge('coverage', value=value, default_color=color, num_padding_chars=1)
 
 
@@ -218,7 +210,7 @@ def get_python_badge():
     return Badge('python', value=value, default_color=color, num_padding_chars=1)
 
 
-def update_readme(name, badge_path, add_to_readme, logger):
+def update_readme(name, badge_filename, add_to_readme, logger):
     """ add badge to readme
     """
     if not add_to_readme:
@@ -227,9 +219,9 @@ def update_readme(name, badge_path, add_to_readme, logger):
     if not accessible(filename):
         logger.warn(f'{filename} does not exist or is not accessible')
         return
-    relative_path = os.path.join('docs', 'images', os.path.basename(badge_path))
-    url = URL.get(name, 'https://pybuilder.io/')
-    line_to_add = f"[![{name}]({relative_path})]({url})\n"
+    # not super clean but is the best we can do for now
+    relative_filename = f"docs/images{badge_filename.split('/docs/images')[1]}"
+    line_to_add = f'![{name}]({relative_filename})\n'
     with open('README.md', 'r+') as file_handler:
         lines = file_handler.readlines()
         for line in lines:
@@ -242,49 +234,49 @@ def update_readme(name, badge_path, add_to_readme, logger):
             file_handler.writelines(lines)
 
 
-def write_badge_and_update_readme(name, badge, badge_path, logger, add_to_readme):
-    """ write badge and update readme
-    """
-    logger.info(f'writing coverage badge {badge_path}')
-    badge.write_badge(badge_path, overwrite=True)
-    update_readme(name, badge_path, add_to_readme, logger)
-
-
-def create_complexity_badge(report_path, badge_path, logger, add_to_readme, use_average):
+def create_complexity_badge(report_filename, badge_filename, logger, add_to_readme, use_average):
     """ create complexity badge from radon report
     """
-    if accessible(report_path):
-        complexity_data = get_complexity_report(read_lines(report_path))
-        badge = get_complexity_badge(complexity_data, use_average=use_average)
-        write_badge_and_update_readme('complexity', badge, badge_path, logger, add_to_readme)
-    else:
-        logger.warn(f'{report_path} is not accessible')
+    if not accessible(report_filename):
+        logger.warn(f'{report_filename} does not exist or is not accessible')
+        return
+    lines = read_lines(report_filename)
+    report = get_complexity_report(lines)
+    badge = get_complexity_badge(report, use_average=use_average)
+    logger.info(f'writing complexity badge {badge_filename}')
+    badge.write_badge(badge_filename, overwrite=True)
+    update_readme('complexity', badge_filename, add_to_readme, logger)
 
 
-def create_severity_badge(report_path, badge_path, logger, add_to_readme):
+def create_severity_badge(report_filename, badge_filename, logger, add_to_readme):
     """ create severity badge from bandit report
     """
-    if accessible(report_path):
-        severity_data = read_data(report_path)
-        badge = get_severity_badge(severity_data)
-        write_badge_and_update_readme('severity', badge, badge_path, logger, add_to_readme)
-    else:
-        logger.warn(f'{report_path} is not accessible')
+    if not accessible(report_filename):
+        logger.warn(f'{report_filename} does not exist or is not accessible')
+        return
+    severity_report = read_data(report_filename)
+    badge = get_severity_badge(severity_report)
+    logger.info(f'writing severity badge {badge_filename}')
+    badge.write_badge(badge_filename, overwrite=True)
+    update_readme('severity', badge_filename, add_to_readme, logger)
 
 
-def create_coverage_badge(report_path, badge_path, logger, add_to_readme):
+def create_coverage_badge(report_filename, badge_filename, logger, add_to_readme):
     """ create coverage badge from coverage report
     """
-    if accessible(report_path):
-        coverage_data = get_coverage(read_data(report_path))
-        badge = get_coverage_badge(coverage_data)
-        write_badge_and_update_readme('coverage', badge, badge_path, logger, add_to_readme)
-    else:
-        logger.warn(f'{report_path} is not accessible')
+    if not accessible(report_filename):
+        logger.warn(f'{report_filename} does not exist or is not accessible')
+        return
+    data = read_data(report_filename)
+    coverage = get_coverage(data)
+    badge = get_coverage_badge(coverage)
+    logger.info(f'writing coverage badge {badge_filename}')
+    badge.write_badge(badge_filename, overwrite=True)
+    update_readme('coverage', badge_filename, add_to_readme, logger)
 
 
-def create_python_badge(badge_path, logger, add_to_readme):
-    """ create python version badge
-    """
+def create_python_badge(badge_filename, logger, add_to_readme):
     badge = get_python_badge()
-    write_badge_and_update_readme('python', badge, badge_path, logger, add_to_readme)
+    logger.info(f'writing python version badge {badge_filename}')
+    badge.write_badge(badge_filename, overwrite=True)
+    update_readme('python', badge_filename, add_to_readme, logger)
